@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Pg;
 use Carp;
 
-our $VERSION = '1.2';
+our $VERSION = '1.3';
 our $Debug = 0;
 has pg => sub { +{} };
 
@@ -107,13 +107,27 @@ sub _quick_query {
     } else {
         # INSERT (default field name = id)
         if ($type eq 'INSERT') {
-        # get primary key from table 
+        # get primary key from table
+        my $PK = 'id'; # default PK column is 'id'
         my $pkey =  $self->pg->db->query(qq{SELECT a.attname FROM pg_index i JOIN pg_attribute a ON a.attrelid = i.indrelid
                                          AND a.attnum = ANY(i.indkey) WHERE  i.indrelid = '$table_name'::regclass AND i.indisprimary
-                                         ORDER BY a.attnum DESC})->hash;
-        $sql .= ' returning ' . $pkey->{attname};
+                                         ORDER BY a.attnum DESC});
+        # if id exists in PKeys get it, else - get last elem
+        while (my $next = $pkey->hash) {
+             if ( $next->{attname} eq 'id' ) {
+                # Note that "finish" needs to be called if you are not fetching all the possible rows
+                $pkey->finish;
+                last;
+             }
+             else {
+                $PK = $next->{attname};
+             }
+        }
+        
+        $sql .= ' returning ' . $PK;
+        
             eval {
-            return $self->pg->db->query($sql, @bind_params)->hash->{$pkey->{attname}};
+            return $self->pg->db->query($sql, @bind_params)->hash->{$PK};
             };
         } else {
         # delete/update
